Griffin® PowerBlock Micro Universal – RadioShack
Description: Power Block Universal Micro is a super-small AC wall charger for your mobile or smartphone, GPS, camera, MP3, and more. Just use the cable that came with your d

# Griffin® PowerBlock Micro Universal

Catalog #: 2731080
$11.99

Compare at $19.99

Quantity

This product is out of stock online. To see if it's available at a store near you, please click the Find In Store button.

- Find In Store
- Send to Friend
- Print

Power Block Universal Micro is a super-small AC wall charger for your mobile or smartphone, GPS, camera, MP3, and more. Just use the cable that came with your device. Rated at 5 watts for fast, safe charging from your 100 to 240 V AC wall outlet. Fold-flat non-polarized blades make Power Block Universal Micro a well-mannered traveling companion.

#### Similar Items

## Please enter ZIP code:

Enter 5 digit zip code

Loading...